/*
  User Interface with touch pad and lcd display
  BV4612
  Copyright (c) 2013 Jim Spence.  All right reserved.
  www.byvac.com - see terms and conditions for using hardware
  
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/  

// Version 1.0

#ifndef _H_bv4612_h
#define _H_bv4612_h

#include <stdio.h>
#include <stdint.h>
#include <wiringPi.h>
#include <wiringPiI2C.h>


#ifdef __cplusplus
extern "C" {
#endif

extern  int bv4612_join(uint8_t i2caddress);
extern  void clrBuf(int bus);
extern  uint8_t keysBuf(int bus);
extern  uint8_t key(int bus);
extern  uint8_t keyIn(int bus,uint8_t k);
extern  uint8_t scan(int bus);
extern  void bl(int bus,uint8_t v);
extern  void average(int bus,uint16_t *b);
extern  void delta(int bus,uint16_t *b);
extern  void EEreset(int bus);
extern  void sleep(int bus);
        // EEPROM settings
extern  void trigger(int bus,uint16_t value);
extern  void hyst(int bus,uint8_t value);
extern  void keyPtr(int bus,uint8_t value);
extern  void keySize(int bus,uint8_t value);
extern  void debounce(int bus,uint8_t value);
extern  void repeat(int bus,uint16_t value);
extern  void timebase(int bus,uint8_t value);  
extern  void defaultBL(int bus,uint8_t value);      
        // system section
extern  void EEWrite(int bus,uint8_t adr, uint8_t value);
extern  uint8_t EEread(int bus,uint8_t adr);
extern  uint16_t ID(int bus);
void Version(int bus, char *s);
        // lcd section      
extern  void lcd_init(int bus);
extern  void lcd_write(int bus,uint8_t);
extern  void lcd_string(int bus, int row, int col, char *s);
extern  void lcd_contrast(int bus,uint8_t v);
extern  void lcd_bl(int bus,uint8_t v);
extern  void lcd_clear(int bus);
extern  void lcd_home(int bus);
extern  void lcd_sendKeyCmd(int bus,uint8_t cmd);
extern  void lcd_lcd_cmd(int bus,uint8_t cmd);
extern  void lcd_cmd(int bus,uint8_t cmd);
extern  void lcd_setCursor(int bus,uint8_t col, uint8_t row);


#ifdef __cplusplus
}
#endif


#endif