// BV4242 is a touch keypad with LCD front panel
// sends message to lcd and returns any keys pressed
//
#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <wiringPi.h>
#include <wiringPiI2C.h>
#include "bv4612.h"

// From I2C tools
// Parse a CHIP-ADDRESS command line argument and return the corresponding
// chip address, or a negative value if the address is invalid.
//
int parse_i2c_address(const char *address_arg)
{
        long address;
        char *end;

        address = strtol(address_arg, &end, 0);
        if (*end || !*address_arg) {
                fprintf(stderr, "Error: Chip address is not a number!\n");
                return -1;
        }
        if (address < 0x03 || address > 0x77) {
                fprintf(stderr, "Error: Chip address out of range "
                        "(0x03-0x77)!\n");
                return -2;
        }

        return address;
}

int main(int argc, char *argv[])
{
int8_t row,col,i2c_address;
char *s,buf[30];

    if(argc != 5) {
        printf("\nUsage: bv4612_lcd <i2caddress> <row> <column> <message>");
        return 1;
    } else {
        if((i2c_address=parse_i2c_address(argv[1])) < 0) return 1;
        row=atoi(argv[2]);
        col=atoi(argv[3]);
    }

    int pad=bv4612_join(i2c_address); // attache to bus
    
    printf("\nI2C address = %x",i2c_address);
    Version(pad,buf);
    printf("\nFirmware Version %s\n",buf);
    
    lcd_clear(pad);
    lcd_string(pad,row,col,argv[4]);
      
    char k = key(pad);
    if(k) printf("\nKeys in buffer \n");
    
    while(k) {
        printf(" %d",k);
        k = key(pad);
    }      
    
    return 0;
}


