// BV4612 is a touch keypad with LCD front panel
// This helps to tune the EERPOM settings
//
#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <wiringPi.h>
#include <wiringPiI2C.h>
#include "bv4612.h"

// From I2C tools
// Parse a CHIP-ADDRESS command line argument and return the corresponding
// chip address, or a negative value if the address is invalid.
//
int parse_i2c_address(const char *address_arg)
{
        long address;
        char *end;

        address = strtol(address_arg, &end, 0);
        if (*end || !*address_arg) {
                fprintf(stderr, "Error: Chip address is not a number!\n");
                return -1;
        }
        if (address < 0x03 || address > 0x77) {
                fprintf(stderr, "Error: Chip address out of range "
                        "(0x03-0x77)!\n");
                return -2;
        }

        return address;
}

// use
// bv4612_tune number of times, default is 30
int main(int argc, char *argv[])
{
uint16_t avg[10], delt[10], j, count=30;
int8_t k, i2c_address,buf[30];

    if(argc != 3) {
        printf("\nUsage: bv4612_tune <i2caddress> <count>");
        printf("\nCount is the number of times the average and delta are shown");
        printf("\ntry 10 at first");
        return 1;
    } else {
        if((i2c_address=parse_i2c_address(argv[1])) < 0) return 1;
        count=atoi(argv[2]);
    }

    int pad=bv4612_join(i2c_address); // attache to bus
    
    printf("\nI2C address = %x",i2c_address);
    printf("\nCount set to = %d",count);
    Version(pad,buf);
    printf("\nFirmware Version %s\n",buf);
    
    while (count--) {
        // get 8 average and delta values
        average(pad, &avg[0]);
        delay(10);
        delta(pad, &delt[0]);

        // print them out
        printf("\n\n");
        for(j=0; j<8; j++) printf("%4d ",avg[j]);
        printf("\n");
        for(j=0; j<8; j++) printf("%4d ",delt[j]);

        delay(500); //for(j=0;j<=500;j++); usleep(1000000); // 500 mS
        if((k=key(pad))) {
            printf(" Decoded as %d",k);
            clrBuf(pad);
        }
    }
    printf("\n");
    return 0;
}


